==> ah-formbuilder-1.0.28.tgz: package/es/reducers/formReducer.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import _ from "lodash";
export default (function (state, action) {
  var _extends2;

  if (state === void 0) {
    state = {
      data: {},
      predefined: [],
      predefinedEndpoint: null,
      fileUploadUrl: null,
      newFieldData: null,
      conditionableFields: [],
      order: 1,
      locals: [],
      theme: {},
      supportedLanguages: [],
      addLanguageSelect: '',
      currentLang: '',
      isOptionUpdated: false
    };
  }

  var data = _.cloneDeep(state.data);

  switch (action.type) {
    case 'CREATE_FIELD':
      return _extends({}, state, {
        newFieldData: action.payload.data
      });

    case 'UPDATE_FIELD':
      var order = state.order;

      if (state.newFieldData) {
        if (data) {
          if (!state.newFieldData.parentId) {
            for (var index in data) {
              if (action.payload.data.order <= data[index].order) {
                data[index].order = data[index].order + 1;
              }
            }
          }
        }

        if (!state.newFieldData.parentId) order++;
      }

      var newUpdateData = _extends({}, data, (_extends2 = {}, _extends2[action.payload.data.uuid] = action.payload.data, _extends2));

      return _extends({}, state, {
        data: newUpdateData,
        order: order,
        newFieldData: null
      });

    case 'DELETE_FIELD':
      var deleteData = _.cloneDeep(data);

      if (deleteData[action.payload.id].type === 'section') {
        for (var _index in deleteData) {
          if (deleteData[_index].parentId === action.payload.id) delete deleteData[_index];
        }
      }

      delete deleteData[action.payload.id];
      return _extends({}, state, {
        data: deleteData
      });

    case 'SET_PREDEFINED':
      return _extends({}, state, {
        predefined: action.payload.data
      });

    case 'SET_PREDEFINED_ENDPOINT':
      return _extends({}, state, {
        predefinedEndpoint: action.payload.data
      });

    case 'SET_FILE_UPLOAD_URL':
      return _extends({}, state, {
        fileUploadUrl: action.payload.data
      });

    case 'ADD_PREDEFINED_CATEGORY':
      var preCategories = _.cloneDeep(state.predefined);

      preCategories = preCategories.filter(function (item) {
        var _action$payload, _action$payload$data;

        return item.slug !== (action == null ? void 0 : (_action$payload = action.payload) == null ? void 0 : (_action$payload$data = _action$payload.data) == null ? void 0 : _action$payload$data.slug);
      });
      preCategories.push(action.payload.data);
      return _extends({}, state, {
        predefined: preCategories
      });

    case 'UPDATE_CATEGORY_OPTIONS':
      var predefined = _.cloneDeep(state.predefined);

      for (var i = 0; i < predefined.length; i++) {
        if (predefined[i].slug === action.payload.slug) {
          predefined[i].options = action.payload.options;
          break;
        }
      }

      return _extends({}, state, {
        predefined: predefined,
        isOptionUpdated: true
      });

    case 'SET_IS_OPTION_UPDATED':
      return _extends({}, state, {
        isOptionUpdated: action.payload
      });

    case 'SET_INITIAL':
      return _extends({}, state, {
        data: action.payload.data
      });

    case 'DELETE_NEW_FIELD':
      return _extends({}, state, {
        newFieldData: null
      });

    case 'SET_ORDER':
      return _extends({}, state, {
        order: action.payload.data
      });

    case 'SET_CONDITIONABLE_FIELDS':
      return _extends({}, state, {
        conditionableFields: action.payload.data
      });

    case 'SET_LOCALS':
      return _extends({}, state, {
        locals: action.payload.data
      });

    case 'SET_THEME':
      return _extends({}, state, {
        theme: action.payload.data
      });

    case 'SET_CURRENT_LANGUAGE':
      return _extends({}, state, {
        currentLang: action.payload.data
      });

    case 'SET_ADD_LANGUAGE_SELECT':
      return _extends({}, state, {
        addLanguageSelect: action.payload.data
      });

    default:
      return state;
  }
});

==> ah-formbuilder-1.0.30.tgz: package/es/reducers/formReducer.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import _ from "lodash";
export default (function (state, action) {
  var _extends2;

  if (state === void 0) {
    state = {
      data: {},
      predefined: [],
      predefinedEndpoint: null,
      fileUploadUrl: null,
      newFieldData: null,
      conditionableFields: [],
      order: 1,
      locals: [],
      theme: {},
      supportedLanguages: [],
      addLanguageSelect: '',
      currentLang: '',
      isOptionUpdated: false,
      users: []
    };
  }

  var data = _.cloneDeep(state.data);

  switch (action.type) {
    case 'CREATE_FIELD':
      return _extends({}, state, {
        newFieldData: action.payload.data
      });

    case 'UPDATE_FIELD':
      var order = state.order;

      if (state.newFieldData) {
        if (data) {
          if (!state.newFieldData.parentId) {
            for (var index in data) {
              if (action.payload.data.order <= data[index].order) {
                data[index].order = data[index].order + 1;
              }
            }
          }
        }

        if (!state.newFieldData.parentId) order++;
      }

      var newUpdateData = _extends({}, data, (_extends2 = {}, _extends2[action.payload.data.uuid] = action.payload.data, _extends2));

      return _extends({}, state, {
        data: newUpdateData,
        order: order,
        newFieldData: null
      });

    case 'DELETE_FIELD':
      var deleteData = _.cloneDeep(data);

      if (deleteData[action.payload.id].type === 'section') {
        for (var _index in deleteData) {
          if (deleteData[_index].parentId === action.payload.id) delete deleteData[_index];
        }
      }

      delete deleteData[action.payload.id];
      return _extends({}, state, {
        data: deleteData
      });

    case 'SET_PREDEFINED':
      return _extends({}, state, {
        predefined: action.payload.data
      });

    case 'SET_USERS':
      return _extends({}, state, {
        users: action.payload.data
      });

    case 'SET_PREDEFINED_ENDPOINT':
      return _extends({}, state, {
        predefinedEndpoint: action.payload.data
      });

    case 'SET_FILE_UPLOAD_URL':
      return _extends({}, state, {
        fileUploadUrl: action.payload.data
      });

    case 'ADD_PREDEFINED_CATEGORY':
      var preCategories = _.cloneDeep(state.predefined);

      preCategories = preCategories.filter(function (item) {
        var _action$payload, _action$payload$data;

        return item.slug !== (action == null ? void 0 : (_action$payload = action.payload) == null ? void 0 : (_action$payload$data = _action$payload.data) == null ? void 0 : _action$payload$data.slug);
      });
      preCategories.push(action.payload.data);
      return _extends({}, state, {
        predefined: preCategories
      });

    case 'UPDATE_CATEGORY_OPTIONS':
      var predefined = _.cloneDeep(state.predefined);

      for (var i = 0; i < predefined.length; i++) {
        if (predefined[i].slug === action.payload.slug) {
          predefined[i].options = action.payload.options;
          break;
        }
      }

      return _extends({}, state, {
        predefined: predefined,
        isOptionUpdated: true
      });

    case 'SET_IS_OPTION_UPDATED':
      return _extends({}, state, {
        isOptionUpdated: action.payload
      });

    case 'SET_INITIAL':
      return _extends({}, state, {
        data: action.payload.data
      });

    case 'DELETE_NEW_FIELD':
      return _extends({}, state, {
        newFieldData: null
      });

    case 'SET_ORDER':
      return _extends({}, state, {
        order: action.payload.data
      });

    case 'SET_CONDITIONABLE_FIELDS':
      return _extends({}, state, {
        conditionableFields: action.payload.data
      });

    case 'SET_LOCALS':
      return _extends({}, state, {
        locals: action.payload.data
      });

    case 'SET_THEME':
      return _extends({}, state, {
        theme: action.payload.data
      });

    case 'SET_CURRENT_LANGUAGE':
      return _extends({}, state, {
        currentLang: action.payload.data
      });

    case 'SET_ADD_LANGUAGE_SELECT':
      return _extends({}, state, {
        addLanguageSelect: action.payload.data
      });

    default:
      return state;
  }
});
